==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/sv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Delat med andra",
    "Shared with you" : "Delat med dig",
    "Shared by link" : "Delat som länk",
    "Deleted shares" : "Raderade delningar",
    "Shares" : "Delningar",
    "Nothing shared with you yet" : "Inget delat med dig ännu",
    "Files and folders others share with you will show up here" : "Filer och mappar som andra delar med dig kommer visas här",
    "Nothing shared yet" : "Inget delat ännu",
    "Files and folders you share will show up here" : "Filer och mappar som du delar kommer visas här",
    "No shared links" : "Inga delade länkar",
    "Files and folders you share by link will show up here" : "Filer och mappar som du delar som länkar kommer visas här",
    "No deleted shares" : "Inga raderade delningar",
    "Shares you deleted will show up here" : "Raderade delningar visas här",
    "No shares" : "Inga delningar",
    "Shares will show up here" : "Delningar visas här",
    "Restore share" : "Återställ delning",
    "Something happened. Unable to restore the share." : "Ett fel uppstod. Kan inte återställa delningen.",
    "Move or copy" : "Flytta eller kopiera",
    "Download" : "Ladda ned",
    "Delete" : "Radera",
    "You can upload into this folder" : "Du kan ladda upp i denna mapp",
    "Terms of service" : "Användarvilkor",
    "No compatible server found at {remote}" : "Ingen kompatibel server hittad på {remote}",
    "Invalid server URL" : "Ogiltig server URL",
    "Failed to add the public link to your Nextcloud" : "Misslyckades skapa den offentliga delningslänken till ditt moln",
    "Share" : "Dela",
    "No expiration date set" : "Inget utgångsdatum satt",
    "Shared by" : "Delad av",
    "Sharing" : "Delning",
    "File shares" : "Fildelningar",
    "Downloaded via public link" : "Nedladdad via offentlig länk",
    "Downloaded by {email}" : "Nedladdad av {email}",
    "{file} downloaded via public link" : "{file} nedladdad via offentlig länk",
    "{email} downloaded {file}" : "{email} laddade ned {file}",
    "Shared with group {group}" : "Delad med grupp {group}",
    "Removed share for group {group}" : "Tog bort delning för grupp {group}",
    "{actor} shared with group {group}" : "{actor} delade med gruppen {group}",
    "{actor} removed share for group {group}" : "{actor} tog bort delningen för gruppen {group}",
    "You shared {file} with group {group}" : "Du delade {file} med gruppen {group}",
    "You removed group {group} from {file}" : "Du tog bort gruppen {group} från {file}",
    "{actor} shared {file} with group {group}" : "{actor} delade {file} med gruppen {group}",
    "{actor} removed group {group} from {file}" : "{actor} tog bort gruppen {group} från {file}",
    "Shared as public link" : "Delades offentligt",
    "Removed public link" : "Tog bort offentlig länk",
    "Public link expired" : "Tidsgräns för offentlig länk har löpt ut",
    "{actor} shared as public link" : "{actor} delade offentligt",
    "{actor} removed public link" : "{actor} tog bort offentlig länk",
    "Public link of {actor} expired" : "Offentlig länk av {actor} har utgått",
    "You shared {file} as public link" : "Du delade {file} offentligt",
    "You removed public link for {file}" : "Du tog bort den offentliga länken för {file}",
    "Public link expired for {file}" : "Offentlig länk har utgått för {file}",
    "{actor} shared {file} as public link" : "{actor} delade {file} offentligt",
    "{actor} removed public link for {file}" : "{actor} tog bort den offentliga länken för {file}",
    "Public link of {actor} for {file} expired" : "Offentlig länk av {actor} för {file} har utgått",
    "{user} accepted the remote share" : "{user} accepterade extern delning",
    "{user} declined the remote share" : "{user} nekade extern delning",
    "You received a new remote share {file} from {user}" : "Du har fått en ny extern delning {file} från {user}",
    "{user} accepted the remote share of {file}" : "{user} accepterade extern delning av {file}",
    "{user} declined the remote share of {file}" : "{user} nekade extern delning av {file}",
    "{user} unshared {file} from you" : "{user} slutade dela {file} med dig",
    "Shared with {user}" : "Delade med {user}",
    "Removed share for {user}" : "Tog bort delningen för {user}",
    "You removed yourself" : "Du tog bort dig själv",
    "{actor} removed themselves" : "{actor} tog bort sig själva",
    "{actor} shared with {user}" : "{actor} delade med {user}",
    "{actor} removed share for {user}" : "{actor} tog bort delningen för {user}",
    "Shared by {actor}" : "Delad av {actor}",
    "{actor} removed share" : "{actor} tog bort delning",
    "You shared {file} with {user}" : "Du delade {file} med {user}",
    "You removed {user} from {file}" : "Du tog bort {user} från {file}",
    "You removed yourself from {file}" : "Du tog bort dig själv från {file}",
    "{actor} removed themselves from {file}" : "{actor} tog bort sig från {file}",
    "{actor} shared {file} with {user}" : "{actor} delade {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} tog bort {user} från {file}",
    "{actor} shared {file} with you" : "{actor} delade {file} med dig",
    "{actor} removed you from the share named {file}" : "{actor} raderade dig från delningen med namn {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "En fil eller mapp som delats via mejl eller offentlig länk har blivit <strong>nedladdad</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mapp delades från <strong>en annan server</strong>",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mapp har <strong>delats</strong>",
    "Wrong share ID, share doesn't exist" : "Fel delnings-ID, delningen finns inte",
    "could not delete share" : "kunde inte ta bort delningen",
    "Could not delete share" : "Kunde inte ta bort delningen",
    "Please specify a file or folder path" : "Ange sökväg till filen eller mappen",
    "Wrong path, file/folder doesn't exist" : "Fel sökväg, fil/mapp finns inte",
    "Could not create share" : "Kunde inte skapa delning",
    "invalid permissions" : "ogiltiga behörigheter",
    "Please specify a valid user" : "Ange en giltig användare",
    "Group sharing is disabled by the administrator" : "Gruppdelning är avstängt",
    "Please specify a valid group" : "Ange en giltig grupp",
    "Public link sharing is disabled by the administrator" : "Offentlig delningslänk är avstängt",
    "Public upload disabled by the administrator" : "Offentlig uppladdning är avstängt",
    "Public upload is only possible for publicly shared folders" : "Offentlig uppladdning fungerar endast i offentligt delade mappar",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Dela %s och skicka lösenordet via Nextcloud Talk går inte eftersom Nextcloud Talk är inte aktiverad",
    "Invalid date, date format must be YYYY-MM-DD" : "Ogiltigt datum, måste anges: ÅÅÅÅ-MM-DD",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Delning %1$s misslyckades. Ej tillåtet med delningar från typ %2$s",
    "You cannot share to a Circle if the app is not enabled" : "Du kan inte dela till en cirkel om appen inte är aktiverad",
    "Please specify a valid circle" : "Vänligen ange en giltig cirkel",
    "Sharing %s failed because the back end does not support room shares" : "Dela %s misslyckades eftersom systemet inte stödjer rum-delningar",
    "Unknown share type" : "Ogiltig delningstyp",
    "Not a directory" : "Inte en mapp",
    "Could not lock path" : "Kunde inte låsa sökvägen",
    "Wrong or no update parameter given" : "Fel eller ingen uppdateringsparameter angiven",
    "Can't change permissions for public share links" : "Det går inte att ändra behörigheterna för offentliga länkar",
    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Delning och skicka lösenordet via Nextcloud Talk går inte eftersom Nextcloud Talk är inte aktiverad",
    "Cannot increase permissions" : "Kan inte utöka behörigheter",
    "shared by %s" : "delad av %s",
    "Download all files" : "Ladda ner alla filer",
    "Direct link" : "Direktlänk",
    "Add to your Nextcloud" : "Lägg till i molnet",
    "Share API is disabled" : "Delning av API är inaktiverad",
    "File sharing" : "Fildelning",
    "No entries found in this folder" : "Inga filer hittades i denna mapp",
    "Name" : "Namn",
    "Share time" : "Delningstid",
    "Expiration date" : "Utgångsdatum",
    "Sorry, this link doesn’t seem to work anymore." : "Tyvärr, denna länk verkar inte fungera längre.",
    "Reasons might be:" : "Orsaker kan vara:",
    "the item was removed" : "objektet togs bort",
    "the link expired" : "giltighet för länken har gått ut",
    "sharing is disabled" : "delning är inaktiverat",
    "For more info, please ask the person who sent this link." : "För mer information, kontakta den person som skickade den här länken.",
    "Share note" : "Dela kommentar",
    "Toggle grid view" : "Växla rutnätsvy",
    "Download %s" : "Ladda ned %s",
    "Upload files to %s" : "Ladda upp filer till %s",
    "Note" : "Anteckning",
    "Select or drop files" : "Välj eller dra filer hit",
    "Uploading files…" : "Laddar upp filer...",
    "Uploaded files:" : "Uppladdade filer:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Genom att ladda upp filer godkänner du %1$sanvändarvillkoren %2$s.",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delningen av %s misslyckades. Ej tillåtet med delning av %s",
    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Password" : "Lösenord"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/sv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Delat med andra",
    "Shared with you" : "Delat med dig",
    "Shared by link" : "Delat som länk",
    "Deleted shares" : "Raderade delningar",
    "Shares" : "Delningar",
    "Nothing shared with you yet" : "Inget delat med dig ännu",
    "Files and folders others share with you will show up here" : "Filer och mappar som andra delar med dig kommer visas här",
    "Nothing shared yet" : "Inget delat ännu",
    "Files and folders you share will show up here" : "Filer och mappar som du delar kommer visas här",
    "No shared links" : "Inga delade länkar",
    "Files and folders you share by link will show up here" : "Filer och mappar som du delar som länkar kommer visas här",
    "No deleted shares" : "Inga raderade delningar",
    "Shares you deleted will show up here" : "Raderade delningar visas här",
    "No shares" : "Inga delningar",
    "Shares will show up here" : "Delningar visas här",
    "Restore share" : "Återställ delning",
    "Something happened. Unable to restore the share." : "Ett fel uppstod. Kan inte återställa delningen.",
    "Move or copy" : "Flytta eller kopiera",
    "Download" : "Ladda ned",
    "Delete" : "Radera",
    "You can upload into this folder" : "Du kan ladda upp i denna mapp",
    "Terms of service" : "Användarvilkor",
    "No compatible server found at {remote}" : "Ingen kompatibel server hittad på {remote}",
    "Invalid server URL" : "Ogiltig server URL",
    "Failed to add the public link to your Nextcloud" : "Misslyckades skapa den offentliga delningslänken till ditt moln",
    "Share" : "Dela",
    "No expiration date set" : "Inget utgångsdatum satt",
    "Shared by" : "Delad av",
    "Sharing" : "Delning",
    "File shares" : "Fildelningar",
    "Downloaded via public link" : "Nedladdad via offentlig länk",
    "Downloaded by {email}" : "Nedladdad av {email}",
    "{file} downloaded via public link" : "{file} nedladdad via offentlig länk",
    "{email} downloaded {file}" : "{email} laddade ned {file}",
    "Shared with group {group}" : "Delad med grupp {group}",
    "Removed share for group {group}" : "Tog bort delning för grupp {group}",
    "{actor} shared with group {group}" : "{actor} delade med gruppen {group}",
    "{actor} removed share for group {group}" : "{actor} tog bort delningen för gruppen {group}",
    "You shared {file} with group {group}" : "Du delade {file} med gruppen {group}",
    "You removed group {group} from {file}" : "Du tog bort gruppen {group} från {file}",
    "{actor} shared {file} with group {group}" : "{actor} delade {file} med gruppen {group}",
    "{actor} removed group {group} from {file}" : "{actor} tog bort gruppen {group} från {file}",
    "Shared as public link" : "Delades offentligt",
    "Removed public link" : "Tog bort offentlig länk",
    "Public link expired" : "Tidsgräns för offentlig länk har löpt ut",
    "{actor} shared as public link" : "{actor} delade offentligt",
    "{actor} removed public link" : "{actor} tog bort offentlig länk",
    "Public link of {actor} expired" : "Offentlig länk av {actor} har utgått",
    "You shared {file} as public link" : "Du delade {file} offentligt",
    "You removed public link for {file}" : "Du tog bort den offentliga länken för {file}",
    "Public link expired for {file}" : "Offentlig länk har utgått för {file}",
    "{actor} shared {file} as public link" : "{actor} delade {file} offentligt",
    "{actor} removed public link for {file}" : "{actor} tog bort den offentliga länken för {file}",
    "Public link of {actor} for {file} expired" : "Offentlig länk av {actor} för {file} har utgått",
    "{user} accepted the remote share" : "{user} accepterade extern delning",
    "{user} declined the remote share" : "{user} nekade extern delning",
    "You received a new remote share {file} from {user}" : "Du har fått en ny extern delning {file} från {user}",
    "{user} accepted the remote share of {file}" : "{user} accepterade extern delning av {file}",
    "{user} declined the remote share of {file}" : "{user} nekade extern delning av {file}",
    "{user} unshared {file} from you" : "{user} slutade dela {file} med dig",
    "Shared with {user}" : "Delade med {user}",
    "Removed share for {user}" : "Tog bort delningen för {user}",
    "You removed yourself" : "Du tog bort dig själv",
    "{actor} removed themselves" : "{actor} tog bort sig själva",
    "{actor} shared with {user}" : "{actor} delade med {user}",
    "{actor} removed share for {user}" : "{actor} tog bort delningen för {user}",
    "Shared by {actor}" : "Delad av {actor}",
    "{actor} removed share" : "{actor} tog bort delning",
    "You shared {file} with {user}" : "Du delade {file} med {user}",
    "You removed {user} from {file}" : "Du tog bort {user} från {file}",
    "You removed yourself from {file}" : "Du tog bort dig själv från {file}",
    "{actor} removed themselves from {file}" : "{actor} tog bort sig från {file}",
    "{actor} shared {file} with {user}" : "{actor} delade {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} tog bort {user} från {file}",
    "{actor} shared {file} with you" : "{actor} delade {file} med dig",
    "{actor} removed you from the share named {file}" : "{actor} raderade dig från delningen med namn {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "En fil eller mapp som delats via e-post eller offentlig länk har blivit <strong>nedladdad</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mapp delades från <strong>en annan server</strong>",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mapp har <strong>delats</strong>",
    "Wrong share ID, share doesn't exist" : "Fel delnings-ID, delningen finns inte",
    "could not delete share" : "kunde inte ta bort delningen",
    "Could not delete share" : "Kunde inte ta bort delningen",
    "Please specify a file or folder path" : "Ange sökväg till filen eller mappen",
    "Wrong path, file/folder doesn't exist" : "Fel sökväg, fil/mapp finns inte",
    "Could not create share" : "Kunde inte skapa delning",
    "invalid permissions" : "ogiltiga behörigheter",
    "Please specify a valid user" : "Ange en giltig användare",
    "Group sharing is disabled by the administrator" : "Gruppdelning är avstängt",
    "Please specify a valid group" : "Ange en giltig grupp",
    "Public link sharing is disabled by the administrator" : "Offentlig delningslänk är avstängt",
    "Public upload disabled by the administrator" : "Offentlig uppladdning är avstängt",
    "Public upload is only possible for publicly shared folders" : "Offentlig uppladdning fungerar endast i offentligt delade mappar",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Dela %s och skicka lösenordet via Nextcloud Talk går inte eftersom Nextcloud Talk är inte aktiverad",
    "Invalid date, date format must be YYYY-MM-DD" : "Ogiltigt datum, måste anges: ÅÅÅÅ-MM-DD",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Delning %1$s misslyckades. Ej tillåtet med delningar från typ %2$s",
    "You cannot share to a Circle if the app is not enabled" : "Du kan inte dela till en cirkel om appen inte är aktiverad",
    "Please specify a valid circle" : "Vänligen ange en giltig cirkel",
    "Sharing %s failed because the back end does not support room shares" : "Dela %s misslyckades eftersom systemet inte stödjer rum-delningar",
    "Unknown share type" : "Ogiltig delningstyp",
    "Not a directory" : "Inte en mapp",
    "Could not lock path" : "Kunde inte låsa sökvägen",
    "Wrong or no update parameter given" : "Fel eller ingen uppdateringsparameter angiven",
    "Can't change permissions for public share links" : "Det går inte att ändra behörigheterna för offentliga länkar",
    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Delning och skicka lösenordet via Nextcloud Talk går inte eftersom Nextcloud Talk är inte aktiverad",
    "Cannot increase permissions" : "Kan inte utöka behörigheter",
    "shared by %s" : "delad av %s",
    "Download all files" : "Ladda ned alla filer",
    "Direct link" : "Direktlänk",
    "Add to your Nextcloud" : "Lägg till i molnet",
    "Share API is disabled" : "Delning av API är inaktiverad",
    "File sharing" : "Fildelning",
    "No entries found in this folder" : "Inga filer hittades i denna mapp",
    "Name" : "Namn",
    "Share time" : "Delningstid",
    "Expiration date" : "Utgångsdatum",
    "Sorry, this link doesn’t seem to work anymore." : "Tyvärr, denna länk verkar inte fungera längre.",
    "Reasons might be:" : "Orsaker kan vara:",
    "the item was removed" : "objektet togs bort",
    "the link expired" : "giltighet för länken har gått ut",
    "sharing is disabled" : "delning är inaktiverat",
    "For more info, please ask the person who sent this link." : "För mer information, kontakta den person som skickade den här länken.",
    "Share note" : "Dela kommentar",
    "Toggle grid view" : "Växla rutnätsvy",
    "Download %s" : "Ladda ned %s",
    "Upload files to %s" : "Ladda upp filer till %s",
    "Note" : "Anteckning",
    "Select or drop files" : "Välj eller dra filer hit",
    "Uploading files…" : "Laddar upp filer...",
    "Uploaded files:" : "Uppladdade filer:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Genom att ladda upp filer godkänner du %1$sanvändarvillkoren %2$s.",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delningen av %s misslyckades. Ej tillåtet med delning av %s",
    "This share is password-protected" : "Den här delningen är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Password" : "Lösenord"
},
"nplurals=2; plural=(n != 1);");
